#!/usr/bin/env ruby
require 'diaria/blog'
require 'diaria/config'
require 'diaria/input'

require 'yaml'
require 'getoptlong'

$title = nil
$body = nil
$conf = Config.new
$debug = false

def usage
    puts <<EOF
Usage: #{$0} [command] [command-options] [command-arguments]
	where command is add, edit, remove, etc add is the default if non
	are specified
	
	
Example: #{$0} -t "News Flash" -b tmp.txt
	 #{$0} -t "Another Example"
	 or even just plain old
	 #{$0}
command-options 
	-v or --verbose	Turns on debugging info
	-t or --title specify title of post
	-b or --body  specify a file to be used as body of post
	-c or --config use a different config file than default.
	-h or --help  displays this message
	
diaria is a tool for posting daily news to your website.
#[$0} run with no options
EOF
end

def get_next_id( data_dir="#{$conf.data_dir}" )
	last_id = -1
	
	dir = Dir.open( File.expand_path( data_dir ) )
	dir.each do | file |
		if( file =~ /([0-9]*)\.blog/ )
			i = $1.to_i
			if( i > last_id )
				last_id = i
			end
		end
	end
	last_id = last_id + 1
	last_id
end

opts = GetoptLong.new(
	[ "--title",	"-t",		GetoptLong::REQUIRED_ARGUMENT ],
	["--body",		"-b",		GetoptLong::REQUIRED_ARGUMENT ],
	["--help",		"-h",		GetoptLong::NO_ARGUMENT ],
	["--config",		"-c",		GetoptLong::REQUIRED_ARGUMENT ],
	["--verbose",		"-v",		GetoptLong::NO_ARGUMENT ] 
)
opts.each do | opt, arg |
	if( opt == "--title" )
		$title = arg
	elsif( opt == "--body" )
		tmp = Array.new
		File.open( arg ) do | f |
			f.each do |line|
				tmp.push line
			end
		end
		$body = tmp.join()
	elsif( opt == "--config" )
		$conf = Config.new( arg )
	elsif( opt == "--help" )
		usage()
		exit
	elsif( opt == "--verbose" )
		$debug = true		
	end
end
entry = Content.new
entry.id = get_next_id
entry.date = Time.now
entry.title = ""
entry.body = ""
if( $title == nil )
	entry.title = UserInput.fill("Title:")
else
	entry.title = $title
end
if( $body == nil )
	entry.body = UserInput.fill( "Body:")
else
	entry.body = $body
end
if $debug 
	puts entry.to_yaml
end
YamlEncoder.encode_file( "#{$conf.data_dir}/#{entry.id}.blog", entry )
require 'diaria/publish'
