#!/usr/bin/env ruby

require 'runit/testcase'
require 'ftools'

class Config
    def Config.ensure_user_home_dir        	
        begin
            @@user_home_dir = File.expand_path("~")
    	rescue ArgumentError
    	    #try windows WIN32?
    	    @@user_home_dir = File.expand_path(ENV["USERPROFILE"])
    	end
    	if( File.exists?(@@user_home_dir) )
    	    if $debug
	        puts "Using #{@@user_home_dir} as your home directory"
	    end
    	else
    	    if $debug
	        puts "I can't figure out where your 'home' directory is! Hard code where you want your #{$0} stuff stored. #{__FILE__}:#{__LINE__}"
	    end
    	end    	
    end
    
    Config.ensure_user_home_dir()
    #default values for our configuration
    @@vars = Hash.new
    @@vars["data_dir"] =  File.join(@@user_home_dir, ".diaria", "data")
    @@vars["template_dir"] = File.join(@@user_home_dir, ".diaria","templates")
    @@vars["html_dir"] = File.join(@@user_home_dir, "blog")
    @@vars["rss_filename"] = "rss.xml"
    @@vars["archive_link_prefix"] = "" 
    
    #create config instance data
    #attr_reader :html_dir
    @@vars.each do |key, value|
        eval "attr_reader :#{key}"
    end
    def initialize( config_file=nil )
    	@@vars.each do |key, value|
    	    #load instance data
    	    #@html_dir = @@vars['html_dir']
    	    eval "@#{key} = @@vars['#{key}']"
    	end
    	if( config_file == nil )
    	    config_file = File.join( @@user_home_dir, ".diariarc")
    	end
    	if( File.exists? config_file )    	 
    	    File.open( config_file, "r" ) do | f |
    	        f.each do | line |
    	            comment = Regexp.new("^#.*$")
    	            if( comment =~ line )
    	            	if $debug
	    	        	puts "comment #{line}"
	    	        end
    	            else
    	            	tmp = line.gsub(/#?(.*)=(.*)/,  '@\1 = "\2"' )
    	            	if $debug
			        puts "Evaling #{tmp}"
			end
    	      	    	eval tmp
    	            end
    	            
    	        end
    	    end
    	else
    	    create_config( config_file )
        end
        if $debug
                puts "data_dir is #{@data_dir}"
	        puts "template_dir is #{@template_dir}"
	        puts "html_dir is #{@html_dir}"
	end
        ensure_dirs
        ensure_templates()
    end
    
    def create_config( file )
    	puts "Creating configuration file #{file}"
        conf = File.new( file, 'w' )
        @@vars.each do | k, v |
	            conf.write "#{k}=#{v}" << $/
        end
        conf.close
    end
    def ensure_dirs
        @@vars.each do | k, v |            
            if k =~ /dir/            	
            	if ! File.exists? v
            	    puts "Creating #{v}"
            	    File.mkpath( v )
            	end
            end            
        end
    end
    def ensure_templates
    	if(! File.exists?( File.join(@template_dir,"header.html") ) )
    	    require 'diaria/template_data'
    	    puts "Creating templates  in #{@template_dir}. Edit to customize your site"
    	    output( @template_dir )
    	end
    end
end

class TestConfig < RUNIT::TestCase
    def test_data_dir
	conf = Config.new("/home/auking/r/diaria/doc/config.sample")
    	assert_equals("/home/auking/test/data",conf.data_dir)
	assert_equals("/home/auking/test/blog", conf.html_dir)
	assert_equals("/home/auking/test/templates", conf.template_dir)
        #    @@vars["template_dir"] = File.join(@@user_home_dir, ".diaria","templates")
    end
end

#Standalone driver
if $0 == __FILE__
  require 'runit/cui/testrunner'
  RUNIT::CUI::TestRunner.run(TestConfig.suite)
end
